@echo off

rem Copyright (c) 2008-2011 MechSoft Mechanical and Software Solutions
rem
rem This program is free software: you can redistribute it and/or modify
rem it under the terms of the GNU Lesser General Public License as published by
rem the Free Software Foundation, either version 3 of the License, or
rem (at your option) any later version.
rem
rem This program is distributed in the hope that it will be useful,
rem but WITHOUT ANY WARRANTY; without even the implied warranty of
rem MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
rem GNU Lesser General Public License for more details.
rem
rem You should have received a copy of the GNU Lesser General Public License
rem along with this program.  If not, see <http://www.gnu.org/licenses/>.

if "%OS%" == "Windows_NT" setlocal
rem ---------------------------------------------------------------------------
rem Start/Stop Script for the SIWPAS Server
rem
rem Environment Variable Prerequisites
rem
rem   SIWPAS_HOME   May point at your Siwpas "build" directory.
rem
rem   SIWPAS_BASE   (Optional) Base directory for resolving dynamic portions
rem                   of a Siwpas installation.  If not present, resolves to
rem                   the same directory that SIWPAS_HOME points to.
rem
rem   SIWPAS_OPTS   (Optional) Java runtime options used when the "start",
rem                   or "run" command is executed.
rem
rem   SIWPAS_TMPDIR (Optional) Directory path location of temporary directory
rem                   the JVM should use (java.io.tmpdir).  Defaults to
rem                   %SIWPAS_BASE%\temp.
rem
rem   JAVA_HOME       Must point at your Java Development Kit installation.
rem                   Required to run the with the "debug" argument.
rem
rem   JRE_HOME        Must point at your Java Runtime installation.
rem                   Defaults to JAVA_HOME if empty.
rem
rem   JAVA_OPTS       (Optional) Java runtime options used when the "start",
rem                   "stop", or "run" command is executed.
rem
rem   JAVA_ENDORSED_DIRS (Optional) Lists of of semi-colon separated directories
rem                   containing some jars in order to allow replacement of APIs 
rem                   created outside of the JCP (i.e. DOM and SAX from W3C). 
rem                   It can also be used to update the XML parser implementation.
rem                   Defaults to $SIWPAS_HOME/endorsed.
rem
rem   JPDA_TRANSPORT  (Optional) JPDA transport used when the "jpda start"
rem                   command is executed. The default is "dt_socket".
rem
rem   JPDA_ADDRESS    (Optional) Java runtime options used when the "jpda start"
rem                   command is executed. The default is 8000.
rem
rem   JPDA_SUSPEND    (Optional) Java runtime options used when the "jpda start"
rem                   command is executed. Specifies whether JVM should suspend
rem                   execution immediately after startup. Default is "n".
rem
rem   JPDA_OPTS       (Optional) Java runtime options used when the "jpda start"
rem                   command is executed. If used, JPDA_TRANSPORT, JPDA_ADDRESS,
rem                   and JPDA_SUSPEND are ignored. Thus, all required jpda
rem                   options MUST be specified. The default is:
rem
rem                   -agentlib:jdwp=transport=%JPDA_TRANSPORT%,
rem                       address=%JPDA_ADDRESS%,server=y,suspend=%JPDA_SUSPEND%
rem
rem   LOGGING_CONFIG  (Optional) Override Siwpas's logging config file
rem                   Example (all one line)
rem                   set LOGGING_CONFIG="-Djava.util.logging.config.file=%SIWPAS_BASE%\conf\logging.properties"
rem
rem   JAAS_CONFIG  (Optional) Override Siwpas's JAAS config file
rem                   Example (all one line)
rem                   JAAS_CONFIG="-Djava.security.auth.login.config=$SIWPAS_BASE/conf/login.config"
rem
rem   LOGGING_MANAGER (Optional) Override Siwpas's logging manager 
rem                   Example (all one line)
rem                   set LOGGING_MANAGER="-Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager"
rem
rem   TITLE           (Optional) Specify the title of Siwpas window. The default
rem                   TITLE is Siwpas if it's not specified.
rem                   Example (all one line)
rem                   set TITLE=Siwpas.Cluster#1.Server#1 [%DATE% %TIME%]
rem
rem
rem
rem $Id: siwpas.bat 1040546 2010-11-30 14:47:34Z markt $
rem ---------------------------------------------------------------------------

rem Suppress Terminate batch job on CTRL+C
if not ""%1"" == ""run"" goto mainEntry
if ""%TEMP%"" == """" goto mainEntry
if exist "%TEMP%\%~nx0.run" goto mainEntry
echo Y>"%TEMP%\%~nx0.run"
if not exist "%TEMP%\%~nx0.run" goto mainEntry
echo Y>"%TEMP%\%~nx0.Y"
call "%~f0" %* <"%TEMP%\%~nx0.Y"
rem Use provided errorlevel
set RETVAL=%ERRORLEVEL%
del /Q "%TEMP%\%~nx0.Y" >NUL 2>&1
exit /B %RETVAL%
:mainEntry
del /Q "%TEMP%\%~nx0.run" >NUL 2>&1

rem Guess SIWPAS_HOME if not defined
set "CURRENT_DIR=%cd%"
if not "%SIWPAS_HOME%" == "" goto gotHome
set "SIWPAS_HOME=%CURRENT_DIR%"
if exist "%SIWPAS_HOME%\bin\siwpas.bat" goto okHome
cd ..
set "SIWPAS_HOME=%cd%"
cd "%CURRENT_DIR%"
:gotHome
if exist "%SIWPAS_HOME%\bin\siwpas.bat" goto okHome
echo The SIWPAS_HOME environment variable is not defined correctly
echo This environment variable is needed to run this program
goto end
:okHome

rem Ensure that any user defined CLASSPATH variables are not used on startup,
rem but allow them to be specified in setenv.bat, in rare case when it is needed.
set CLASSPATH=

rem Get standard environment variables
if "%SIWPAS_BASE%" == "" goto gotSetenvHome
if exist "%SIWPAS_BASE%\bin\setenv.bat" call "%SIWPAS_BASE%\bin\setenv.bat"
goto gotSetenvBase
:gotSetenvHome
if exist "%SIWPAS_HOME%\bin\setenv.bat" call "%SIWPAS_HOME%\bin\setenv.bat"
:gotSetenvBase

rem Get standard Java environment variables
if exist "%SIWPAS_HOME%\bin\setclasspath.bat" goto okSetclasspath
echo Cannot find "%SIWPAS_HOME%\bin\setclasspath.bat"
echo This file is needed to run this program
goto end
:okSetclasspath
set "BASEDIR=%SIWPAS_HOME%"
call "%SIWPAS_HOME%\bin\setclasspath.bat" %1
if errorlevel 1 goto end

rem Add on extra jar file to CLASSPATH
rem Note that there are no quotes as we do not want to introduce random
rem quotes into the CLASSPATH
if "%CLASSPATH%" == "" goto emptyClasspath
set "CLASSPATH=%CLASSPATH%;"
:emptyClasspath
set "CLASSPATH=%CLASSPATH%%SIWPAS_HOME%\bin\bootstrap.jar;%SIWPAS_HOME%\bin\license.jar;%SIWPAS_HOME%\bin\bcastlegpg.jar;%SIWPAS_HOME%\bin\bcastleprov.jar"

if not "%SIWPAS_BASE%" == "" goto gotBase
set "SIWPAS_BASE=%SIWPAS_HOME%"
:gotBase

if not "%SIWPAS_TMPDIR%" == "" goto gotTmpdir
set "SIWPAS_TMPDIR=%SIWPAS_BASE%\temp"
:gotTmpdir

rem Add tomcat-juli.jar to classpath
rem tomcat-juli.jar can be over-ridden per instance
if not exist "%SIWPAS_BASE%\bin\tomcat-juli.jar" goto juliClasspathHome
set "CLASSPATH=%CLASSPATH%;%SIWPAS_BASE%\bin\tomcat-juli.jar"
goto juliClasspathDone
:juliClasspathHome
set "CLASSPATH=%CLASSPATH%;%SIWPAS_HOME%\bin\tomcat-juli.jar"
:juliClasspathDone

if not "%LOGGING_CONFIG%" == "" goto noJuliConfig
set LOGGING_CONFIG=-Dnop
if not exist "%SIWPAS_BASE%\conf\logging.properties" goto noJuliConfig
set LOGGING_CONFIG=-Djava.util.logging.config.file="%SIWPAS_BASE%\conf\logging.properties"
:noJuliConfig
set JAVA_OPTS=%JAVA_OPTS% %LOGGING_CONFIG%

if not "%JAAS_CONFIG%" == "" goto noJaasConfig
set JAAS_CONFIG=-Dnop
if not exist "%SIWPAS_BASE%\conf\login.config" goto noJaasConfig
set JAAS_CONFIG=-Djava.security.auth.login.config="%SIWPAS_BASE%\conf\login.config"
:noJaasConfig
set JAVA_OPTS=%JAVA_OPTS% %JAAS_CONFIG%


if not "%LOGGING_MANAGER%" == "" goto noJuliManager
set LOGGING_MANAGER=-Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager
:noJuliManager
set JAVA_OPTS=%JAVA_OPTS% %LOGGING_MANAGER%

rem Add OpenEJB javaagent
if not exist "%SIWPAS_HOME%\lib\openejb-agent.jar" goto openJpaAgentDone
set "JAVA_OPTS=%JAVA_OPTS% -javaagent:%SIWPAS_HOME%\lib\openejb-agent.jar=enabled=false,debug=false"

:openJpaAgentDone

rem ----- Execute The Requested Command ---------------------------------------

echo Using SIWPAS_BASE:   "%SIWPAS_BASE%"
echo Using SIWPAS_HOME:   "%SIWPAS_HOME%"
echo Using SIWPAS_TMPDIR: "%SIWPAS_TMPDIR%"
if ""%1"" == ""debug"" goto use_jdk
echo Using JRE_HOME:        "%JRE_HOME%"
goto java_dir_displayed
:use_jdk
echo Using JAVA_HOME:       "%JAVA_HOME%"
:java_dir_displayed
echo Using CLASSPATH:       "%CLASSPATH%"

set _EXECJAVA=%_RUNJAVA%
set MAINCLASS=org.apache.catalina.startup.Bootstrap
set ACTION=start
set SECURITY_POLICY_FILE=
set DEBUG_OPTS=
set JPDA=

if not ""%1"" == ""jpda"" goto noJpda
set JPDA=jpda
if not "%JPDA_TRANSPORT%" == "" goto gotJpdaTransport
set JPDA_TRANSPORT=dt_socket
:gotJpdaTransport
if not "%JPDA_ADDRESS%" == "" goto gotJpdaAddress
set JPDA_ADDRESS=8000
:gotJpdaAddress
if not "%JPDA_SUSPEND%" == "" goto gotJpdaSuspend
set JPDA_SUSPEND=n
:gotJpdaSuspend
if not "%JPDA_OPTS%" == "" goto gotJpdaOpts
set JPDA_OPTS=-agentlib:jdwp=transport=%JPDA_TRANSPORT%,address=%JPDA_ADDRESS%,server=y,suspend=%JPDA_SUSPEND%
:gotJpdaOpts
shift
:noJpda

if ""%1"" == ""debug"" goto doDebug
if ""%1"" == ""run"" goto doRun
if ""%1"" == ""start"" goto doStart
if ""%1"" == ""stop"" goto doStop
if ""%1"" == ""version"" goto doVersion

echo Usage:  siwpas ( commands ... )
echo commands:
echo   debug             Start Siwpas in a debugger
echo   debug -security   Debug Siwpas with a security manager
echo   jpda start        Start Siwpas under JPDA debugger
echo   run               Start Siwpas in the current window
echo   run -security     Start in the current window with security manager
echo   start             Start Siwpas in a separate window
echo   start -security   Start in a separate window with security manager
echo   stop              Stop Siwpas
echo   version           What version of siwpas are you running?
goto end

:doDebug
shift
set _EXECJAVA=%_RUNJDB%
set DEBUG_OPTS=-sourcepath "%SIWPAS_HOME%\..\..\java"
if not ""%1"" == ""-security"" goto execCmd
shift
echo Using Security Manager
set "SECURITY_POLICY_FILE=%SIWPAS_BASE%\conf\catalina.policy"
goto execCmd

:doRun
shift
if not ""%1"" == ""-security"" goto execCmd
shift
echo Using Security Manager
set "SECURITY_POLICY_FILE=%SIWPAS_BASE%\conf\catalina.policy"
goto execCmd

:doStart
shift
if not "%OS%" == "Windows_NT" goto noTitle
if "%TITLE%" == "" set TITLE=Siwpas
set _EXECJAVA=start "%TITLE%" %_RUNJAVA%
goto gotTitle
:noTitle
set _EXECJAVA=start %_RUNJAVA%
:gotTitle
if not ""%1"" == ""-security"" goto execCmd
shift
echo Using Security Manager
set "SECURITY_POLICY_FILE=%SIWPAS_BASE%\conf\catalina.policy"
goto execCmd

:doStop
shift
set ACTION=stop
set SIWPAS_OPTS=
goto execCmd

:doVersion
%_EXECJAVA% -classpath "%SIWPAS_HOME%\lib\siwpas-loader.jar" org.ow2.siwpas.Version
goto end


:execCmd
rem Get remaining unshifted command line arguments and save them in the
set CMD_LINE_ARGS=
:setArgs
if ""%1""=="""" goto doneSetArgs
set CMD_LINE_ARGS=%CMD_LINE_ARGS% %1
shift
goto setArgs
:doneSetArgs

rem Execute Java with the applicable properties
if not "%JPDA%" == "" goto doJpda
if not "%SECURITY_POLICY_FILE%" == "" goto doSecurity
%_EXECJAVA% %JAVA_OPTS% %SIWPAS_OPTS% %DEBUG_OPTS% -Djava.endorsed.dirs="%JAVA_ENDORSED_DIRS%" -classpath "%CLASSPATH%" -Dcatalina.base="%SIWPAS_BASE%" -Dcatalina.home="%SIWPAS_HOME%" -Djava.io.tmpdir="%SIWPAS_TMPDIR%" %MAINCLASS% %CMD_LINE_ARGS% %ACTION%
goto end
:doSecurity
%_EXECJAVA% %JAVA_OPTS% %SIWPAS_OPTS% %DEBUG_OPTS% -Djava.endorsed.dirs="%JAVA_ENDORSED_DIRS%" -classpath "%CLASSPATH%" -Djava.security.manager -Djava.security.policy=="%SECURITY_POLICY_FILE%" -Dcatalina.base="%SIWPAS_BASE%" -Dcatalina.home="%SIWPAS_HOME%" -Djava.io.tmpdir="%SIWPAS_TMPDIR%" %MAINCLASS% %CMD_LINE_ARGS% %ACTION%
goto end
:doJpda
if not "%SECURITY_POLICY_FILE%" == "" goto doSecurityJpda
%_EXECJAVA% %JAVA_OPTS% %SIWPAS_OPTS% %JPDA_OPTS% %DEBUG_OPTS% -Djava.endorsed.dirs="%JAVA_ENDORSED_DIRS%" -classpath "%CLASSPATH%" -Dcatalina.base="%SIWPAS_BASE%" -Dcatalina.home="%SIWPAS_HOME%" -Djava.io.tmpdir="%SIWPAS_TMPDIR%" %MAINCLASS% %CMD_LINE_ARGS% %ACTION%
goto end
:doSecurityJpda
%_EXECJAVA% %JAVA_OPTS% %SIWPAS_OPTS% %JPDA_OPTS% %DEBUG_OPTS% -Djava.endorsed.dirs="%JAVA_ENDORSED_DIRS%" -classpath "%CLASSPATH%" -Djava.security.manager -Djava.security.policy=="%SECURITY_POLICY_FILE%" -Dcatalina.base="%SIWPAS_BASE%" -Dcatalina.home="%SIWPAS_HOME%" -Djava.io.tmpdir="%SIWPAS_TMPDIR%" %MAINCLASS% %CMD_LINE_ARGS% %ACTION%
goto end

:end
